@@ -1,11 +1,8 @@
 # -*- coding: utf-8 -*-
-#文件修改重启
-# __author__ = 'Michael Liao'
 import os, sys, time, subprocess
 from watchdog.observers import Observer
 from watchdog.events import FileSystemEventHandler
 class MyFileSystemEventHander(FileSystemEventHandler):
-
     def __init__(self, fn):
         super(MyFileSystemEventHander, self).__init__()
         self.restart = fn
@@ -13,6 +10,7 @@ class MyFileSystemEventHander(FileSystemEventHandler):
     def on_any_event(self, event):
         if event.src_path.endswith('.py'):
             print('* 更新文件：%s' % event.src_path)
+            time.sleep(0.2)
             self.restart()
 class Events:
     command = ['echo', 'ok']
