@@ -8,6 +8,7 @@ from datetime import datetime
 from threading import local
 from .utill import filetype
 from kcweb.utill.cache import cache as kcwcache
+from wsgiref.simple_server import make_server
 class web:
     __name=None
     __appname=None
@@ -17,15 +18,6 @@ class web:
         self.__appname=appname
         if self.__name != '__main__':
             def apps(env, start_response):
-                # REQUEST_METHOD=env['REQUEST_METHOD'] #GET
-                # QUERY_STRING=env['QUERY_STRING'] #a=1&b=1
-                # RAW_URI=env['RAW_URI'] #/aa/bb/cc?a=1&b=1
-                # SERVER_PROTOCOL=env['SERVER_PROTOCOL'] #HTTP/1.1
-                # HTTP_HOST=env['HTTP_HOST'] #212.129.149.238:39010
-                # HTTP_COOKIE=env['HTTP_COOKIE'] #cookie
-                # REMOTE_ADDR=env['REMOTE_ADDR'] #27.156.27.201
-                # PATH_INFO=env['PATH_INFO'] #/aa/bb/cc
-                # HTTP_USER_AGENT=env['HTTP_USER_AGENT'] #Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36 SE 2.X MetaSr 1.0
                 try:
                     env['BODY_DATA']=str(env['wsgi.input'].next(), encoding = "utf-8")
                 except:
@@ -49,73 +41,29 @@ class web:
                             ("Content-Type",kind.mime),
                             ("Cache-Control","public, max-age=43200"),
                             ("Accept-Ranges","bytes"),
-                            # ("Content-Length",len(body))
                         ]
                 else:
                     status,resheader,body=self.__routes(self,env)
-                    body=bytes(body, encoding='utf-8')
-                # print(env['bodydata'])
-                # print("\n\nwsgi.input",env['wsgi.input'])
-                # print("\n\ndir(env['wsgi.input'])",dir(env['wsgi.input']))
-                # print("\n\nenv['wsgi.input'].__dict__",env['wsgi.input'].__dict__)
-                # try:
-                #     print("\n\nwsgi.input.buf()",env['wsgi.input'].buf())
-                # except Exception as e:
-                #     print("\n\nwsgi.input.buf() error:",e)
-                # try:
-                #     print("\n\nwsgi.input.next()",env['wsgi.input'].next())
-                # except Exception as e:
-                #     print("\n\nwsgi.input.next() error:",e)
-                # try:
-                #     print("\n\nwsgi.input.read()",env['wsgi.input'].read())
-                # except Exception as e:
-                #     print("\n\nwsgi.input.read() error:",e)
-                # try:
-                #     print("\n\nwsgi.input.reader()",env['wsgi.input'].reader())
-                # except Exception as e:
-                #     print("\n\nwsgi.input.reader() error:",e)
-                # try:
-                #     print("\n\nwsgi.input.readline()",env['wsgi.input'].readline())
-                # except Exception as e:
-                #     print("\n\nwsgi.input.readline() error:",e)
-                # try:
-                #     print("\n\nwsgi.input.readlines()",env['wsgi.input'].readlines())
-                # except Exception as e:
-                #     print("\n\nwsgi.input.readlines() error:",e)
-                # try:
-                #     print("wsgi.input.aa",env['wsgi.input'].get("SCRIPT_NAME", ""))
-                # except Exception as e:
-                #     print("wsgi.input.get('aa') error:",e)
-                # try:
-                #     print("wsgi.input.aa",env['wsgi.input']['aa'])
-                # except Exception as e:
-                #     print("wsgi.input['aa'] error:",e)
-                # print(dir(env['wsgi.input']).getsize)
-                # from io import StringIO
-                # stdout = StringIO()
-                # print("Hello world!", file=stdout)
-                # print(file=stdout)
-                # h = sorted(env.items())
-                # for k,v in h:
-                #     print(k,'=',repr(v), file=stdout)
-                # print(stdout.getvalue().encode("utf-8"))
+                    if type(body) is bytes:
+                        pass
+                    else:
+                        body=bytes(body, encoding='utf-8')
                 start_response(status,resheader)
                 return [body]
             return apps
         else:
             return super().__new__(self)
-    def run(self,filename,host="127.0.0.1",port="39001",name='python3'):
+    def run(self,host="127.0.0.1",port="39001",name='python'):
         """运行开发环境
 
-        filename: 命令行脚本名称
-
         host: 监听地址
         
         port: 端口
 
-        name: python命令行解释机名字 默认python3
+        name: python命令行解释机名字 默认python
         """
         if len(sys.argv)==1 or (len(sys.argv)==2 and sys.argv[1]=='eventlog'):
+            filename=sys.argv[0][:-3]
             if self.__config.app['app_debug']:
                 arg=sys.argv
                 if len(arg)==2 and arg[1]=='eventlog':
@@ -150,16 +98,36 @@ class web:
                     'BODY_DATA':''
                 }
                 status,resheader,body=self.__routes(reqheader)
-                print(body)
+                if 'body' not in body and 'html' not in body and '<' not in body and '>' not in body:
+                    print(body)
             exit()
     def __impl(self,host,port,filename):
         "运行测试服务器"
         try:
-            self.__http_server(
-                host=host,
-                port=port,
-                filename=filename
-            )
+            if config.app['http_server']=='wsgiref':
+                self.__http_wsgi(
+                    host=host,
+                    port=port,
+                    filename=filename
+                )
+            elif config.app['http_server']=='kcweb':
+                self.__http_sever(
+                    host=host,
+                    port=port,
+                    filename=filename
+                )
+            elif config.app['http_server']=='kcweb_server':
+                self.__http_server(
+                    host=host,
+                    port=port,
+                    filename=filename
+                )
+            else:
+                self.__http_wsgi(
+                    host=host,
+                    port=port,
+                    filename=filename
+                )
         except KeyboardInterrupt:
             pass
     def __get_modular(self,header):
@@ -219,11 +187,11 @@ class web:
         routedefault=route['default']
         methods=route['methods']
         if routedefault:
-            edition='index'
+            plug='index'
             files=route['files']
             funct=route['funct']
         else:
-            edition=''
+            plug=''
             files=''
             funct=''
         param=[]
@@ -233,8 +201,8 @@ class web:
         ##默认路由start #################################################################################
         
         if modular:
-            if route['edition']:  #匹配模块并且匹配了版本
-                edition=route['edition']
+            if route['plug']:  #匹配模块并且匹配了插件
+                plug=route['plug']
                 routedefault,PATH_INFO=web.__getconfigroute(
                     self,
                     PATH_INFO,
@@ -252,7 +220,7 @@ class web:
                             else:
                                 param.append(urllib.parse.unquote(path))
                         i+=1
-            else:                  #配置模块没有配置版本
+            else:                  #配置模块没有配置插件
                 routedefault,PATH_INFO=web.__getconfigroute(
                     self,
                     PATH_INFO,
@@ -262,7 +230,7 @@ class web:
                     for path in PATH_INFO:
                         if path:
                             if i==0:
-                                edition=path
+                                plug=path
                             elif i==1:
                                 files=path
                                 urls=urls+"/"+str(path)
@@ -272,8 +240,8 @@ class web:
                             else:
                                 param.append(urllib.parse.unquote(path))
                         i+=1
-        elif route['edition']:  #配置版本的但没有匹配模块
-            edition=route['edition']
+        elif route['plug']:  #配置版本的但没有匹配插件
+            plug=route['plug']
             routedefault,PATH_INFO=web.__getconfigroute(
                 self,
                 PATH_INFO,
@@ -295,23 +263,24 @@ class web:
                     i+=1
         else: #完全默认
             routedefault,PATH_INFO=web.__getconfigroute(self,PATH_INFO,header)
-            for path in PATH_INFO:
-                if path:
-                    if i==0:
-                        modular=path
-                    elif i==1:
-                        edition=path
-                    elif i==2:
-                        files=path
-                        urls=urls+"/"+str(path)
-                    elif i==3:
-                        funct=path
-                        urls=urls+"/"+str(path)
-                    else:
-                        param.append(urllib.parse.unquote(path))
-                i+=1
+            if routedefault: #使用默认路由
+                for path in PATH_INFO:
+                    if path:
+                        if i==0:
+                            modular=path
+                        elif i==1:
+                            plug=path
+                        elif i==2:
+                            files=path
+                            urls=urls+"/"+str(path)
+                        elif i==3:
+                            funct=path
+                            urls=urls+"/"+str(path)
+                        else:
+                            param.append(urllib.parse.unquote(path))
+                    i+=1
         #默认路由end ############################################################
-        return methods,modular,edition,files,funct,tuple(param)
+        return methods,modular,plug,files,funct,tuple(param)
     def __tran(self,data,status,resheader):
         "转换控制器返回的内容"
         if isinstance(data,tuple):
@@ -356,8 +325,9 @@ class web:
         resheader={"Content-Type":"text/html; charset=utf-8"}
         web.__set_globals(self,header)
         PATH_INFO=header['PATH_INFO'].split('/')
-        del PATH_INFO[0]
-        methods,modular,edition,files,funct,param=web.defaultroute(self,header,PATH_INFO)
+        if PATH_INFO[0]==' ' or PATH_INFO[0]=='':
+            del PATH_INFO[0]
+        methods,modular,plug,files,funct,param=web.defaultroute(self,header,PATH_INFO)
         if header['REQUEST_METHOD'] in methods:
             try:
                 obj=getattr(web.__appname,modular)
@@ -380,9 +350,9 @@ class web:
                     )
                 else:
                     try:
-                        obj=getattr(obj,edition)
+                        obj=getattr(obj,plug)
                     except (AttributeError,UnboundLocalError) as e:
-                        con="无法找到目录："+str(modular)+"/controller/"+str(edition)+"/"
+                        con="无法找到目录："+str(modular)+"/controller/"+str(plug)+"/"
                         try:
                             data=getattr(obj,"error")(e,con)
                             body,status,resheader=web.__tran(
@@ -411,7 +381,7 @@ class web:
                         try:
                             obj=getattr(obj,files)
                         except (AttributeError,UnboundLocalError) as e:
-                            con="无法找到文件："+str(modular)+"/controller/"+str(edition)+"/"+str(files)+".py"
+                            con="无法找到文件："+str(modular)+"/controller/"+str(plug)+"/"+str(files)+".py"
                             try:
                                 data=getattr(obj,"error")(e,con)
                                 body,status,resheader=web.__tran(
@@ -574,7 +544,11 @@ class web:
         if isinstance(resheaders,list):
             if not body:
                 body=''
-            return str(status),resheaders,str(body)
+            if type(body) is bytes:
+                pass
+            else:
+                body=str(body)
+            return str(status),resheaders,body
         else:
             raise Exception()
     def __tpl(**context):
@@ -585,9 +559,96 @@ class web:
             t=Template(content)
             body=t.render(**context)
         return body
-    
-    
+    def __application(self,env, start_response):
+        # print(env)
+        try:
+            request_body_size = int(env.get('CONTENT_LENGTH', 0))
+        except (ValueError):
+            request_body_size = 0
+        BODY_DATA=env['wsgi.input'].read(request_body_size)
+        if 'multipart/form-data; boundary' in env['CONTENT_TYPE']:
+            BODY_DATA=BODY_DATA.decode("ISO-8859-1")
+            env['BODY_DATA']=BODY_DATA
+            # lists=BODY_DATA.split("\r\n")
+            # BODY_DATA=re.sub(lists[0],'',BODY_DATA)
+            # BODY_DATA=re.sub(lists[1],'',BODY_DATA)
+            # BODY_DATA=re.sub(lists[2],'',BODY_DATA)
+            # BODY_DATA=re.sub(lists[len(lists)-2],'',BODY_DATA)
+        else:
+            env['BODY_DATA']=BODY_DATA.decode()
+        env['RAW_URI']=env['PATH_INFO']
+        if env.get('QUERY_STRING'):
+            env['RAW_URI']=str(env['PATH_INFO'])+"?"+str(env.get('QUERY_STRING'))
+        try:
+            env['REMOTE_ADDR']
+        except:
+            env['REMOTE_ADDR']=''
+        try:
+            env['HTTP_COOKIE']
+        except:
+            env['HTTP_COOKIE']=''
+        try:
+            env['REMOTE_ADDR']
+        except:
+            env['REMOTE_ADDR']=''
+        try:
+            env['HTTP_USER_AGENT']
+        except:
+            env['HTTP_USER_AGENT']=''
+        reqheader={ 
+            'REQUEST_METHOD':env['REQUEST_METHOD'],
+            'RAW_URI':env['RAW_URI'],
+            'PATH_INFO':env['PATH_INFO'],
+            'QUERY_STRING':env['QUERY_STRING'],
+            'SERVER_PROTOCOL':env['SERVER_PROTOCOL'],
+            'HTTP_HOST':env['HTTP_HOST'],
+            'HTTP_COOKIE':env['HTTP_COOKIE'],
+            'REMOTE_ADDR':env['REMOTE_ADDR'],
+            'HTTP_USER_AGENT':env['HTTP_USER_AGENT'],
+            'BODY_DATA':env['BODY_DATA']
+        }
+        p=(config.app['staticpath']+reqheader['RAW_URI'].replace(' ',''))
+        status='200 ok'
+        if os.path.isfile(p):
+            kind = filetype.guess(p)
+            if kind is None:
+                f=open(p,"rb")
+                body=f.read()
+                f.close()
+                resheader=[
+                    ("Cache-Control","public, max-age=43200"),
+                ]
+            else:
+                f=open(p,"rb")
+                body=f.read()
+                f.close()
+                resheader=[
+                    ("Content-Type",kind.mime),
+                    ("Cache-Control","public, max-age=43200"),
+                    ("Accept-Ranges","bytes"),
+                ]
+        else:
+            status,resheader,body=web.__routes(self,reqheader)
+            resheader.append(('Server', "kcweb"+config.kcweb['version']))
+            if type(body) is bytes:
+                pass
+            else:
+                body=bytes(body, encoding='utf-8')
+        start_response(status,resheader)
+        return [body]
+    def __http_wsgi(self,host,port,filename):
+        "http——wsgi测试服务"
+        print("* \033[1;31;40m! 警告：\033[0m这是一个wsgiref开发服务器。不要在生产环境中部署使用它")
+        print('* 生产环境中建议使用gunicorn,gunicorn运行命令如：gunicorn -b '+host+':'+str(port)+' '+str(filename)+':app')
+        if self.__config.app['app_debug']:
+            print('* 调试器：开启')
+        else:
+            print('* 调试器：已关闭')
+        print("* 运行在http://"+host+":"+str(port)+"/ （按CTRL+C退出）")
+        httpd = make_server(host, int(port), self.__application)
+        httpd.serve_forever()
     def __http_server(self,host,port,filename):
+        "http测试服务"
         tcp_socket=socket.socket(socket.AF_INET,socket.SOCK_STREAM)
         try:
             tcp_socket.bind((host,int(port)))
@@ -595,7 +656,7 @@ class web:
             print("通常每个套接字地址(协议/网络地址/端口)只允许使用一次（按CTRL+C退出）")
         else:
             tcp_socket.listen(1024)
-            print('! 警告：这是开发服务器。不要在生产环境中部署使用它')
+            print('! \033[1;31;40m警告：\033[0m这是一个kcweb_server开发服务器。不要在生产环境中部署使用它')
             print('* 生产环境中建议使用gunicorn,gunicorn运行命令如：gunicorn -b '+host+':'+str(port)+' '+str(filename)+':app')
             if self.__config.app['app_debug']:
                 print('* 调试器：开启')
@@ -679,13 +740,16 @@ class web:
                     header+="Content-Length:%d\n" % len(body)
             else:
                 status,resheader,body=self.__routes(reqheader)
-                body=body.encode()
+                if type(body) is bytes:
+                    pass
+                else:
+                    body=body.encode()
                 header="HTTP/1.1 %s \n" % status
                 header+="Content-Length:%d\n" % len(body)
             
             print(HTTP_HOST+' -- ['+str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))+'] "'+REQUEST_METHOD+" "+RAW_URI +" "+SERVER_PROTOCOL + '" '+status+"-")
             t=time.time()
-            header+="Server:kcweb\n"
+            header+="Server:kcweb"+str(config.kcweb['version'])+"\n"
             header+="Date:%s\n" % datetime.utcnow().strftime('%a, %d %b %Y %H:%M:%S GMT')
             for t in resheader:
                 header+="%s:%s\n" % (t[0],t[1])
@@ -696,8 +760,10 @@ class web:
             except Exception as e:
                 pass
         new_socket.close() 
-    def __http_sever(self,host,port):
+    def __http_sever(self,host,port,filename):
         #http测试服务器
+        print('\033[1;31;40m! 警告：\033[0m这是一个kcweb开发服务器。不要在生产环境中部署使用它')
+        print('* 生产环境中建议使用gunicorn,gunicorn运行命令如：gunicorn -b '+host+':'+str(port)+' '+str(filename)+':app')
         if self.__config.app['app_debug']:
             print('* 调试器：开启')
         else:
@@ -709,8 +775,6 @@ class web:
         pack_length=1024
         tcp_socket.setblocking(False)
         tcp_socket_list=list()
-        
-        
         while True:
             try:
                 new_tcp_socket,client_info=tcp_socket.accept()
@@ -755,6 +819,7 @@ class web:
                         else:
                             HTTP_USER_AGENT=''
                         BODY_DATA=datas[len(datas)-1]
+                        # print(data)
                         #reqsest
                         reqheader={ 
                             'REQUEST_METHOD':REQUEST_METHOD,
@@ -769,11 +834,13 @@ class web:
                             'BODY_DATA':BODY_DATA
                         }
                         p=(config.app['staticpath']+RAW_URI.replace(' ',''))
-                        
+                        # print("目录",p)
                         status='200 ok'
                         if os.path.isfile(p):
+                            # print('静态文件',p)
                             kind = filetype.guess(p)
                             if kind is None:
+                                
                                 f=open(p,"rb")
                                 body=f.read()
                                 f.close()
@@ -790,13 +857,16 @@ class web:
                                 header+="Content-Length:%d\n" % len(body)
                         else:
                             status,resheader,body=self.__routes(reqheader)
-                            body=body.encode()
+                            if type(body) is bytes:
+                                pass
+                            else:
+                                body=body.encode()
                             header="HTTP/1.1 %s \n" % status
                             header+="Content-Length:%d\n" % len(body)
                         
                         print(HTTP_HOST+' -- ['+str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))+'] "'+REQUEST_METHOD+" "+RAW_URI +" "+SERVER_PROTOCOL + '" '+status+"-")
                         t=time.time()
-                        header+="Server:kcweb\n"
+                        header+="Server:kcweb"+str(config.kcweb['version'])+"\n"
                         header+="Date:%s\n" % datetime.utcnow().strftime('%a, %d %b %Y %H:%M:%S GMT')
                         for t in resheader:
                             header+="%s:%s\n" % (t[0],t[1])
