@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-from ${appname}.common import *
-#下面的方法在当前模块中有效
-G=globals.G
+from .autoload import *
 #下面的方法在当前模块中有效
 def before_request():
     G.userinfo=get_session("userinfo")
