@@ -22,6 +22,17 @@ class froms:
         except:
             k=None
         return k
+class HEADER:
+    def Method():
+        return kcwglobals.HEADER.Method
+    def URL():
+        return kcwglobals.HEADER.URL
+    def PATH_INFO():
+        return kcwglobals.HEADER.PATH_INFO
+    def SERVER_PROTOCOL():
+        return kcwglobals.HEADER.SERVER_PROTOCOL
+    def HTTP_HOST():
+        return kcwglobals.HEADER.HTTP_HOST
 def get_data():
     "获取请求参数体"
     return kcwglobals.HEADER.BODY_DATA
