@@ -21,7 +21,8 @@ class mysql:
             try:
                 self.__conn.close()
             except Exception as e:
-                print("关闭失败",e)
+                if self.__config['debug']:
+                    print("关闭失败",e)
     __dbcount=1
     def __setdbcount(self):
         "设置数据库配置总数量"
@@ -48,12 +49,13 @@ class mysql:
         if self.__config['pattern']:
             if identifier in mysql.__conn:
                 for k in mysql.__conn[identifier]:
-                    # print(identifier)
                     try:
                         k['obj'].close()
-                        print(k,"关闭成功")
-                    except:
-                        print(k,"关闭错误")
+                        if self.__config['debug']:
+                            print(k,"关闭成功")
+                    except Exception as e:
+                        if self.__config['debug']:
+                            print(k,"连接关闭失败",str(e))
                 mysql.__conn[identifier]=[]
     __dbobjident=None #集中式(单一服务器)并且长连接模式下随机服务器链接标识  和 分布式(主从服务器)模式下随机服务器链接标识
     def __connects(self,typess="DQL"):
@@ -75,10 +77,10 @@ class mysql:
                             masterlistsdb.append(objar)
                             i=i+1
                         mysql.__conn[self.__masteridentifier]=masterlistsdb
-                        print("第%s次创建数据库链接对象，长连接模式" % (self.__errorcounts+1))
+                        if self.__config['debug']:
+                            print("第%s次创建数据库链接对象，长连接模式" % (self.__errorcounts+1))
                 else:
                     mysql.__conn=connect(host=self.__config['host'][0], port=self.__config['port'][0], user=self.__config['user'][0], password=self.__config['password'][0], db=self.__config['db'][0], charset=self.__config['charset'])
-                    # print("第%s次创建数据库链接对象" % (self.__errorcounts+1)+self.__config['host'][0])
             elif self.__config['deploy']==1: # 分布式(主从服务器)
                 if self.__config['pattern']: # 长连接情况下
                     j=0
@@ -92,8 +94,6 @@ class mysql:
                         self.__slaveidentifier=self.__slaveidentifier+self.__config['host'][j]+str(self.__config['port'][j])+self.__config['db'][j] # 从服务器标识
                         j=j+1
                     if self.__masteridentifier not in mysql.__conn or len(mysql.__conn[self.__masteridentifier])<self.__config['master_num']:
-                        # print("有",mysql.__conn)
-                        # print("标识",self.__masteridentifier)
                         j=0
                         masterlistsdb=[] #主服务器实例
                         while j < self.__config['master_num']: #主服务器数量
@@ -105,7 +105,8 @@ class mysql:
                                 i=i+1
                             j=j+1
                         mysql.__conn[self.__masteridentifier]=masterlistsdb
-                        print("第%s次创建数据库链接对象，长连接模式（主）" % (self.__errorcounts+1))
+                        if self.__config['debug']:
+                            print("次创建数据库链接对象，长连接模式（主）" % (self.__errorcounts+1))
                     if self.__slaveidentifier not in mysql.__conn or len(mysql.__conn[self.__slaveidentifier])<self.__dbcount-self.__config['master_num']:
                         
                         j=self.__config['master_num']
@@ -119,7 +120,8 @@ class mysql:
                                 i=i+1
                             j=j+1
                         mysql.__conn[self.__slaveidentifier]=slaveerlistsdb
-                        print("第%s次创建数据库链接对象，长连接模式（从）" % (self.__errorcounts+1))
+                        if self.__config['debug']:
+                            print("创建数据库链接对象，长连接模式（从）" % (self.__errorcounts+1))
                 else:
                     if typess == "DQL": #数据查询语言DQL
                         if self.__config['master_dql']: #所有服务器随机
@@ -131,9 +133,10 @@ class mysql:
                                 db=self.__config['db'][self.__dbobjident], 
                                 charset=self.__config['charset']
                             )
-                            print("第%s次创建所有数据库链接对象" % (self.__errorcounts+1)+self.__config['host'][self.__dbobjident])
+                            if self.__config['debug']:
+                                print("创建所有数据库链接对象" % (self.__errorcounts+1)+self.__config['host'][self.__dbobjident])
                         else: #从服务器随机
-                            self.__dbobjident=random.randint(0,self.__dbcount-self.__config['master_num']-1)
+                            self.__dbobjident=random.randint(self.__config['master_num'],self.__dbcount-1)
                             mysql.__conn=connect(host=self.__config['host'][self.__dbobjident], 
                                 port=self.__config['port'][self.__dbobjident], 
                                 user=self.__config['user'][self.__dbobjident], 
@@ -141,10 +144,11 @@ class mysql:
                                 db=self.__config['db'][self.__dbobjident], 
                                 charset=self.__config['charset']
                             )
-                            print("第%s次创建从数据库链接对象" % (self.__errorcounts+1)+self.__config['host'][self.__dbobjident])
+                            if self.__config['debug']:
+                                print("创建从数据库链接对象" % (self.__errorcounts+1)+self.__config['host'][self.__dbobjident]+str(self.__config['db'][self.__dbobjident]))
                     else:
                          #从服务器随机
-                        self.__dbobjident=random.randint(0,len(self.__config['db']-self.__config['master_num'])-1)
+                        self.__dbobjident=random.randint(self.__config['master_num'],self.__dbcount-1)
                         mysql.__conn=connect(host=self.__config['host'][self.__dbobjident], 
                             port=self.__config['port'][self.__dbobjident], 
                             user=self.__config['user'][self.__dbobjident], 
@@ -152,13 +156,13 @@ class mysql:
                             db=self.__config['db'][self.__dbobjident], 
                             charset=self.__config['charset']
                         )
-                        print("第%s次创建从数据库链接对象" % (self.__errorcounts+1)+self.__config['host'][self.__dbobjident])
+                        if self.__config['debug']:
+                            print("创建从数据库链接对象" % (self.__errorcounts+1)+self.__config['host'][self.__dbobjident]+str(self.__config['db'][self.__dbobjident]))
                     
         except Exception as e: # 铺获未知异常
             try:
                 errcome=tuple(eval(str(e)))[0]
             except Exception as e: # 铺获未知异常
-                # print(self.__sql)
                 raise Exception(e)
             if errcome == 2003: #如果数据库链接失败
                 # self.__closeconn(self.__masteridentifier)
@@ -167,7 +171,8 @@ class mysql:
                     time.sleep(10)
                     self.__errorcounts=self.__errorcounts+1
                     if self.__errorcounts<self.__errorcount*300:
-                        print("无法链接到数据库服务器，准备第%d次重新链接:%s" % (self.__errorcounts,e))
+                        if self.__config['debug']:
+                            print("无法链接到数据库服务器，准备第%d次重新链接:%s" % (self.__errorcounts,e))
                         self.__connects(typess)
                     else:
                         self.__errorcounts=0
@@ -176,7 +181,8 @@ class mysql:
                 else:
                     self.__errorcounts=self.__errorcounts+1
                     if self.__errorcounts<self.__errorcount:
-                        print("无法链接到数据库服务器，开始重新链接")
+                        if self.__config['debug']:
+                            print("无法链接到数据库服务器，开始重新链接")
                         self.__connects(typess)
                     else:
                         self.__errorcounts=0
@@ -233,7 +239,6 @@ class mysql:
                 while i<self.__dbcount:
                     self.__config['db'].append(config)
                     i=i+1
-                # print(self.__config)
             else:
                 print("config类型错误，设置连接不生效")
         return self
@@ -306,26 +311,30 @@ class mysql:
                     self.__cursor=self.__conn.cursor()
                     res=self.__cursor.execute(self.__sql)
         except Exception as e: # 铺获未知异常
-            errorcodes=tuple(eval(str(e)))[0]
+            try:
+                errorcodes=tuple(eval(str(e)))[0]
+            except:
+                errorcodes=0
             if errorcodes == 2013 or errorcodes == 2006 or errorcodes == 2003 or errorcodes == 1053 or errorcodes == 0:  #2013连接丢失、2003数据库无法连接时、1053连接正在被关闭时、2006服务器丢失
                 if self.__config['pattern']: # 长连接情况下
                     if self.__config['cli']==True:
-                        print("等待连接数据库")
+                        if self.__config['debug']:
+                            print("等待连接数据库")
                         if self.__patternerrorcount>self.__config['dbObjcount'] * self.__dbcount: #长连接情况下如果错误次数超过数据实例数量 关闭使用连接进行重连接
                             self.__patternerrorcount=0
                             if self.__config['deploy'] == 1: #分布式(主从服务器) 情况下
-                                print("数据库连接失效，关闭主从连接池后重新连接")
+                                if self.__config['debug']:
+                                    print("数据库连接失效，关闭主从连接池后重新连接")
                                 self.__closeconn(self.__masteridentifier)
                                 self.__closeconn(self.__slaveidentifier)
                                 time.sleep(10)
-                                # mysql.__conn=[] #父类数据库实例
                                 self.__connects(typess)
                                 self.__execute(typess)
                             else:
-                                print("数据库连接失效，关闭主连接池后重新连接")
+                                if self.__config['debug']:
+                                    print("数据库连接失效，关闭主连接池后重新连接")
                                 self.__closeconn(self.__masteridentifier)
                                 time.sleep(10)
-                                # mysql.__conn=[] #父类数据库实例
                                 self.__connects(typess)
                                 self.__execute(typess)
                         else:
@@ -333,29 +342,22 @@ class mysql:
                             self.__execute(typess)
                     else:
                         self.__conn[bs][self.__dbobjident]['error']=self.__conn[bs][self.__dbobjident]['error']+1 #当前数据库连接实例异常错误数量
-                        if self.__conn[bs][self.__dbobjident]['error'] > 2:
+                        if self.__conn[bs][self.__dbobjident]['error'] > 0:
                             try:
-                                mysql.__conn[bs][self.__dbobjident]['obj'].close() #关闭当前实例
+                                # mysql.__conn[bs][self.__dbobjident]['obj'].close() #关闭当前实例
+                                self.__closeconn(bs)
                             except Exception as e:
-                                print("关闭异常",e)
-                            # self.__conn[bs].pos(self.__dbobjident) #从列表中删除
-                            # if errorcodes == 2013:
-                            #创建一个新的数据库实例
-                            if types=='master':
-                                s=random.randint(0,self.__config['master_num']-1)
-                            else:
-                                s=random.randint(self.__dbcount-self.__config['master_num']-1,self.__dbcount-1)
-                            obj=connect(host=self.__config['host'][s], port=self.__config['port'][s], user=self.__config['user'][s], password=self.__config['password'][s], db=self.__config['db'][s], charset=self.__config['charset'])
-                            mysql.__conn[bs][self.__dbobjident]['obj']=obj
-                            mysql.__conn[bs][self.__dbobjident]['error']=0
-                            print("已重新创建一个新的数据库实例",mysql.__conn)
-                        self.__execute(typess)
+                                if self.__config['debug']:
+                                    print("关闭异常",e)
+                        raise Exception(e)
                 else: # 短连接情况下
-                    print("服务器正在被关闭，关闭当前连接后重试")
+                    if self.__config['debug']:
+                        print("服务器正在被关闭，关闭当前连接后重试")
                     try:
                         mysql.__conn.close() #关闭当前实例
                     except Exception as e:
-                        print("关闭异常",e)
+                        if self.__config['debug']:
+                            print("关闭异常",e)
                     # mysql.__conn=[] #父类数据库实例
                     self.__connects(typess)
                     self.__execute(typess)
@@ -376,7 +378,6 @@ class mysql:
         res=self.__execute('DQL')
         description=self.__cursor.description #获取字段
         result = self.__cursor.fetchall() #获取查询结果
-        # print(result)
         self.__cursor.close()
         if description is None:
             return res
@@ -404,7 +405,6 @@ class mysql:
         res=self.__execute('DML')
         description=self.__cursor.description #获取字段
         result = self.__cursor.fetchall() #获取查询结果
-        # print(result)
         self.__cursor.close()
         if description is None:
             return res
@@ -439,7 +439,6 @@ class mysql:
         self.__execute()
         description=self.__cursor.description #获取字段
         result = self.__cursor.fetchall() #获取查询结果
-        # print(result)
         self.__cursor.close()
         lists=[]
         keys =[]
@@ -471,7 +470,6 @@ class mysql:
         self.__execute()
         description=self.__cursor.description #获取字段
         result = self.__cursor.fetchall() #获取查询结果
-        # print(result)
         self.__cursor.close()
 
         item = dict()
@@ -943,7 +941,6 @@ class mysql:
                         s=self.__order+" "+s
                 else:
                     s=self.__order
-                # print(s)
             self.__sql=self.__sql+" ORDER BY "+s
         if self.__group:
             s=self.__group
@@ -963,15 +960,12 @@ class mysql:
                 self.__sql=self.__sql+" "+self.__lock
             else:
                 self.__sql=self.__sql+' FOR UPDATE'
-        # print(self.__sql)
-        # exit()
     def __listTrans(self):
         """列表转换sql表达式
         返回 字符串
         """
         strs=''
         #[('id', 'eq', '1'), 'or', ('id', 'eq', '2')]
-        # print(self.__where)
         for k in self.__where:
             if isinstance(k,tuple):
                 t=0
