@@ -13,25 +13,30 @@ class Http:
     set_encoding="utf-8" #设置text输出编码
     set_session=True #是否启用会话
 
-    get_header={} #响应头
-    get_cookies={} #得到最后的响应cookie
-    get_text='' #得到body响应内容
-    get_content='' #得到二进制内容
-    get_response='' #得到响应对象
-    get_status_code=None #响应状态码
+    get_header={} #获取响应头
+    get_cookies={} #获取最后的响应cookie
+    get_cookie_str='' #获取最后的响应cookie 字符串
+    get_text='' #获取body响应内容
+    get_content='' #获取body响应二进制内容
+    get_response='' #获取响应对象
+    get_status_code=None #获取响应状态码
     
     req=None
     def gettext(self):
         """得到响应text"""
         return self.get_text
-    def openurl(self,url,method="GET",data=None,files=None):
+    def openurl(self,url,method="GET",data=None,files=None,allow_redirects=True):
         """模拟浏览器请求
 
         url : 目标地址
 
-        method ：GET POST
+        method ：GET POST 等
 
         data：请求参数
+
+        file 上传文件
+
+        allow_redirects 是否重定向
         """
         if self.set_session:
             if self.req is None:
@@ -43,7 +48,7 @@ class Http:
                 self.req = requests
         if self.set_cookies and isinstance(self.set_cookies,str):
             self.cookieserTdict()
-        response=self.req.request(method, url,data=data,files=files,proxies=self.set_proxies,cookies=self.set_cookies,headers=self.set_header,timeout=self.set_timeout,verify=self.set_verify)
+        response=self.req.request(method, url,data=data,files=files,proxies=self.set_proxies,cookies=self.set_cookies,headers=self.set_header,timeout=self.set_timeout,verify=self.set_verify,allow_redirects=allow_redirects)
         response.encoding=self.set_encoding
         self.get_header=dict(response.headers)
         cookie=requests.utils.dict_from_cookiejar(response.cookies)
@@ -53,6 +58,11 @@ class Http:
             self.get_cookies=cookie
         if self.set_cookies:
             self.get_cookies=self.__merge(self.set_cookies,self.get_cookies)
+        if self.get_cookies:
+            cookies=''
+            for key in self.get_cookies:
+                cookies=cookies+key+"="+self.get_cookies[key]+";"
+            self.get_cookie_str=cookies
         self.get_text=response.text
         self.get_content=response.content
         self.get_response=response
