@@ -57,6 +57,14 @@ class redis:
         "得到一个redis连接对象，执行更多高级操作"
         self.__connects()
         return self.__redisObj
+    def getstr(self,name):
+        """获取name的值
+
+        name，键
+        返回键“name”处的值，如果该键不存在，则返回“none”
+        """
+        self.__connects()
+        return self.__redisObj.get(name)
     def setstr(self,name,value,ex=None, px=None, nx=False, xx=False):
         """
         name，键
@@ -97,7 +105,7 @@ class redis:
 
         px，过期时间（毫秒）
 
-        nx，如果设置为True，则只有key不存在时，当前set操作才执行,同#setnx(key, value)
+        nx，如果设置为True，则只有key不存在时，当前set操作才执行
 
         xx，如果设置为True，则只有key存在时，当前set操作才执行
         """
@@ -108,6 +116,7 @@ class redis:
                 ex=self.__config['ex']
         value=self.__json_encode(value)
         return self.__redisObj.set(name, value, ex=ex, px=px, nx=nx, xx=xx)
+    
     def get(self,name):
         """获取name的值
 
@@ -115,7 +124,10 @@ class redis:
         返回键“name”处的值，如果该键不存在，则返回“none”
         """
         self.__connects()
-        return self.__json_decode(self.__redisObj.get(name))
+        value=self.__redisObj.get(name)
+        if value:
+            value=self.__json_decode(value)
+        return value
     def delete(self,name):
         """删除name的值
 
@@ -126,7 +138,7 @@ class redis:
         self.__connects()
         return self.__redisObj.delete(name)
     def rpush(self,name, *values):
-        "元素从list的右边加入"
+        "元素从list的右边加入 ，可以添加多个"
         self.__connects()
         # print(self.__config)
         return self.__redisObj.rpush(name, *values) 
@@ -155,7 +167,7 @@ class redis:
         self.__connects()
         return self.__redisObj.lpushx(name)
     def hset(self,name,key,value):
-        """在hash``名称中将'key``设置为'value`'``如果HSET创建了新字段，则返回1，否则返回0
+        """在hash名称中将key设置为value如果HSET创建了新字段，则返回1，否则返回0
         
         name，名
 
@@ -166,15 +178,15 @@ class redis:
         self.__connects()
         return self.__redisObj.hset(name,key,value)
     def hget(self,name,key):
-        "返回散列``name``中的``key``值"
+        "返回hash的name中的key值"
         self.__connects()
         return self.__redisObj.hget(name,key)
     def hgetall(self,name):
-        "返回散列名称/值对的Python dict"
+        "返回hash名称/值对的Python dict"
         self.__connects()
         return self.__redisObj.hgetall(name)
     def hmset(self,name,mapping,ex=None):
-        """在hash“name”中为每个键设置值
+        """在hash的name中为每个键设置值
         name，键
 
         mapping，值
